@@ -1,7 +1,7 @@
 import enum
 from warnings import warn
 from dataclasses import asdict, is_dataclass, replace
-from typing import Any, Callable, NamedTuple, List, Union
+from typing import Any, Callable, NamedTuple, List, Union, TypeVar
 from copy import deepcopy
 from functools import reduce
 import numpy as np
@@ -121,17 +121,21 @@ def parse_base_val(f, t, v, strict=False):
 def parse_list_val(f, t, v, strict=False):
     try:
         item_type = t.__args__[0]
+
     except AttributeError as e:
         raise TypeError(f"field {f} has list type without meta data for element types")
     try:
-
         if strict and not isinstance(v, list):
             raise TypeError('{} must be {}'.format(f, t))
-
+        if(type(item_type) == TypeVar):
+            # Type is a custom type so we should just return the value
+            return v
         if is_base_cls(item_type):
             return v
         # TODO: Can we just pass this back to parse value?
         if is_iterable(item_type):
+            if v is None:
+                return []
             return [parse_list_val(f, item_type, vi) for vi in v]
         if is_dataclass(item_type):
             return [dict_to_cls(vi, item_type, strict) or item_type() for vi in v]
@@ -179,7 +183,7 @@ def parse_enum_val(f, t, v, strict=False):
     try:
         return next(e for e in t if e.value == v)
     except StopIteration:
-        raise ValueError(f'{v} is not a member of enum {t}')
+        raise ValueError(f'{v} is not a member of enum {t}. Valid values are {[e.value for e in t]}')
 
 
 def get_parser(t) -> Callable[[str, type, Any, bool], object]:
